import os from 'os'
import fs from 'fs'
import fsExtra from 'fs-extra'
import compressing from 'compressing'
import { contextBridge } from 'electron'
import { electronAPI } from '@electron-toolkit/preload'

// Custom APIs for renderer
const api = {
    fs,
    fsExtra: fsExtra,
    compressing: compressing,
    homedir: os.homedir(),
    platform: process.platform,
    arch: process.arch,
}

// Use `contextBridge` APIs to expose Electron APIs to
// renderer only if context isolation is enabled, otherwise
// just add to the DOM global.
if (process.contextIsolated) {
    try {
        contextBridge.exposeInMainWorld('electron', electronAPI)
        contextBridge.exposeInMainWorld('api', api)
    } catch (error) {
        console.error(error)
    }
} else {
    window.electron = electronAPI
    window.api = api
}
